- Added functions `xoutil.objects.dict_merge`:func:,
  `xoutil.types.are_instances`:func: and `xoutil.types.no_instances`:func:.

- Deprecated function `xoutil.objects.smart_getattr`:func:.  Use
  `xoutil.objects.get_first_of`:func: instead.
